using UnityEngine;
using NowGG.IAP;
using System;

public class SampleIAPScript : MonoBehaviour
{
    private string app_id = "3";

    void Start()
    {

        if (!NowGG.IAP.NowGGIAPManager.IsNowGGIapAvailable())
            return;

        NowGGProductBuilder.Instance.AddProduct("coin1", ProductType.Consumable);
        NowGGProductBuilder.Instance.AddProduct("coin2", ProductType.Consumable);

        NowGGIAPManager.Instance.OnInitSuccess += OnInitSuccess;
        NowGGIAPManager.Instance.OnInitFailed += OnInitFailed;
        NowGGIAPManager.Instance.OnPurchaseCompleted += OnPurchaseProduct;

        NowGGIAPManager.Instance.Initialize(app_id);
    }

    private void OnInitSuccess()
    {
        Debug.Log($"IAP init success");

        // now you can get product details using product id
        string price = NowGGIAPManager.Instance.GetProductWithID("coin1").price;
        string currencyCode = NowGGIAPManager.Instance.GetProductWithID("coin1").priceCurrencyCode;
    }

    private void OnInitFailed(string reason)
    {
        Debug.Log($"IAP init failed {reason}");
    }

    // call this from UI button click for purchasing a product
    public void PurchaseProduct(string productId)
    {
        NowGGIAPManager.Instance.PurchaseProduct(productId);
    }

    private PurchaseProcessingResult OnPurchaseProduct(PurchasedProduct purchasedProduct)
    {
        // A consumable product has been purchased by this user.
        if (String.Equals(purchasedProduct.productId, "coin1", StringComparison.Ordinal))
        {
            Debug.Log(string.Format("OnPurchaseProduct: PASS. Product: '{0}'", purchasedProduct.productId));
            // The consumable item has been successfully purchased, add 100 coins to the player's in-game score.
            // score += 100;
        }
        else if (String.Equals(purchasedProduct.productId, "coin2", StringComparison.Ordinal))
        {
            Debug.Log(string.Format("OnPurchaseProduct: PASS. Product: '{0}'", purchasedProduct.productId));
            // The consumable item has been successfully purchased, add 200 coins to the player's in-game score.
            // score += 200;
        }
        else
        {
            Debug.Log(string.Format("OnPurchaseProduct: FAIL. Unrecognized product: '{0}'", purchasedProduct.productId));
        }

        // Return a flag indicating whether this product has completely been received, or if the application needs 
        // to be reminded of this purchase at next app launch. Use PurchaseProcessingResult.Pending when still 
        // saving purchased products to the cloud, and when that save is delayed. 

        return PurchaseProcessingResult.Complete;
    }
}

