using System;
using System.Collections.Generic;

namespace gg.now.wallet.Sdk
{

    [System.Serializable]
    public class Extension
    {
        public List<string> accounts;
        public List<string> events;
        public List<string> methods;

        public Extension(List<string> accounts, List<string> events, List<string> methods)
        {
            this.accounts = accounts;
            this.events = events;
            this.methods = methods;
        }
    }

    [System.Serializable]
    public class NamespaceSession
    {
        public List<string> accounts;
        public List<string> events;
        public List<Extension> extensions;
        public List<string> methods;

        public NamespaceSession(List<string> accounts, List<string> events, List<Extension> extensions, List<string> methods)
        {
            this.accounts = accounts;
            this.events = events;
            this.extensions = extensions;
            this.methods = methods;
        }
    }

    [System.Serializable]
    public class Proposal
    {
        public List<string> chains;

        public List<string> methods;
        public List<string> events;
        public List<Extension> extensions;


        public Proposal(List<string> chains, List<string> methods, List<string> events, List<Extension> extensions)
        {
            this.chains = chains;
            this.events = events;
            this.extensions = extensions;
            this.methods = methods;
        }
    }

    [System.Serializable]
    public class AppMetaData
    {
        public string description;
        public List<string> icons;
        public string name;
        public string redirect;
        public string url;

        public AppMetaData(string description, List<string> icons, string name, string redirect, string url)
        {
            this.description = description;
            this.icons = icons;
            this.name = name;
            this.redirect = redirect;
            this.url = url;
        }
    }

    [System.Serializable]
    public class ApprovedSession
    {
        public List<string> accounts;
        public AppMetaData appMetaData;
        public Dictionary<String, NamespaceSession> nameSpaces;
        public string topic;

        public ApprovedSession(List<string> accounts, AppMetaData appMetaData, Dictionary<string, NamespaceSession> nameSpaces, string topic)
        {
            this.accounts = accounts;
            this.appMetaData = appMetaData;
            this.nameSpaces = nameSpaces;
            this.topic = topic;
        }
    }



    [System.Serializable]
    public class SessionEvent
    {
        public string data;
        public string name;

        public SessionEvent(string data, string name)
        {
            this.data = data;
            this.name = name;
        }
    }

    [System.Serializable]
    public class RejectedSession
    {
        public string topic;
        public string reason;

        public RejectedSession(string topic, string reason)
        {
            this.topic = topic;
            this.reason = reason;
        }
    }

    [System.Serializable]
    public class Session
    {
        public string topic;
        public long expiry;
        public Dictionary<String, NamespaceSession> namespaces;
        public AppMetaData metaData;
        public String redirect;

        public Session(string topic, long expiry, Dictionary<string, NamespaceSession> namespaces, AppMetaData metaData)
        {
            this.topic = topic;
            this.expiry = expiry;
            this.namespaces = namespaces;
            this.metaData = metaData;
            this.redirect = metaData.redirect;
        }
    }



    [System.Serializable]
    public class UpdatedSession
    {
        public string topic;
        public Dictionary<String, NamespaceSession> namespaces;

        public UpdatedSession(string topic, Dictionary<string, NamespaceSession> namespaces)
        {
            this.topic = topic;
            this.namespaces = namespaces;
        }
    }

    [System.Serializable]
    public class DeletedSession
    {
        public string topic;
        public string reason;
        public string error;

        public DeletedSession(string topic, string reason, string error)
        {
            this.topic = topic;
            this.reason = reason;
            this.error = error;
        }
    }


    [System.Serializable]
    public class SessionRequestResponse
    {
        public string topic;
        public string chainId;
        public string method;
        public JsonRpcResponse result;

        public SessionRequestResponse(string topic, string chainId, string method, JsonRpcResponse result)
        {
            this.topic = topic;
            this.chainId = chainId;
            this.method = method;
            this.result = result;
        }
    }

    [System.Serializable]
    public class JsonRpcResponse
    {
        public long id;
        public string jsonrpc = "2.0";
        public string result;
        public int code;
        public string message;

        public JsonRpcResponse(long id, string jsonrpc, string result, int code, string message)
        {
            this.id = id;
            this.jsonrpc = jsonrpc;
            this.result = result;
            this.code = code;
            this.message = message;
        }


    }

    [System.Serializable]
    public class Pairing
    {
        public string topic;
        public long expiry;
        public AppMetaData peerAppMetaData;
        public string relayProtocol;
        public string relayData;
        public string uri;
        public bool isActive;
        public string registeredMethods;

        public Pairing(string topic, long expiry, AppMetaData peerAppMetaData, string relayProtocol, string relayData, string uri, bool isActive, string registeredMethods)
        {
            this.topic = topic;
            this.expiry = expiry;
            this.peerAppMetaData = peerAppMetaData;
            this.relayProtocol = relayProtocol;
            this.relayData = relayData;
            this.uri = uri;
            this.isActive = isActive;
            this.registeredMethods = registeredMethods;
        }
    }

    [System.Serializable]
    public class User
    {
        public string avatar;
        public string name;
        public string geo;
        public string emailId;

        public User(string avatar, string name, string geo, string emailId)
        {
            this.avatar = avatar;
            this.name = name;
            this.geo = geo;
            this.emailId = emailId;
        }
    }

    [System.Serializable]
    public class NFTMetaData
    {
        public string name;
        public int price;
        public string image;

        public NFTMetaData(string name, int price, string image)
        {
            this.name = name;
            this.price = price;
            this.image = image;
        }
    }

    [System.Serializable]
    public class Nft
    {
        public string amount;
        public string blockNumber;
        public string blockNumberMinted;
        public string contractType;
        public string lastMetadataSync;

        public string lastTokenUriSync;

        public NFTMetaData metadata;
        public string minterAddress;

        public string name;
        public string ownerOf;
        public string symbol;
        public string tokenAddress;
        public string tokenHash;
        public string tokenId;
        public string tokenUri;

        public Nft(string amount,
            string blockNumber,
            string blockNumberMinted,
            string contractType,
            string lastMetadataSync,
            string lastTokenUriSync,
            NFTMetaData metadata,
            string minterAddress,
            string name,
            string ownerOf,
            string symbol,
            string tokenAddress,
            string tokenHash,
            string tokenId,
            string tokenUri)
        {
            this.amount = amount;
            this.blockNumber = blockNumber;
            this.blockNumberMinted = blockNumberMinted;
            this.contractType = contractType;
            this.lastMetadataSync = lastMetadataSync;
            this.lastTokenUriSync = lastTokenUriSync;
            this.metadata = metadata;
            this.minterAddress = minterAddress;
            this.name = name;
            this.ownerOf = ownerOf;
            this.symbol = symbol;
            this.tokenAddress = tokenAddress;
            this.tokenHash = tokenHash;
            this.tokenId = tokenId;
            this.tokenUri = tokenUri;
        }
    }

    public class TransactionInfo
    {
        public string blockHash;
        public string blockNumber;
        public string contractAddress;
        public string cumulativeGasUsed;
        public string effectiveGasPrice;
        public string from;
        public string gasUsed;
        public List<Logs> logs = new List<Logs>();
        public string logsBloom;
        public string status;
        public string to;
        public string transactionHash;
        public string transactionIndex;
        public string type;

        public TransactionInfo(string blockHash, string blockNumber, string contractAddress, string cumulativeGasUsed, string effectiveGasPrice, string from, string gasUsed, List<Logs> logs, string logsBloom, string status, string to, string transactionHash, string transactionIndex, string type)
        {
            this.blockHash = blockHash;
            this.blockNumber = blockNumber;
            this.contractAddress = contractAddress;
            this.cumulativeGasUsed = cumulativeGasUsed;
            this.effectiveGasPrice = effectiveGasPrice;
            this.from = from;
            this.gasUsed = gasUsed;
            this.logs = logs;
            this.logsBloom = logsBloom;
            this.status = status;
            this.to = to;
            this.transactionHash = transactionHash;
            this.transactionIndex = transactionIndex;
            this.type = type;
        }
    }

    public class Logs
    {

        public string address;
        public string blockHash;
        public string blockNumber;
        public string data;
        public string logIndex;
        public bool removed;
        public List<String> topics = new List<string>();
        public string transactionHash;
        public string transactionIndex;

        public Logs(string address, string blockHash, string blockNumber, string data, string logIndex, bool removed, List<string> topics, string transactionHash, string transactionIndex)
        {
            this.address = address;
            this.blockHash = blockHash;
            this.blockNumber = blockNumber;
            this.data = data;
            this.logIndex = logIndex;
            this.removed = removed;
            this.topics = topics;
            this.transactionHash = transactionHash;
            this.transactionIndex = transactionIndex;
        }
    }


}



