using gg.now.wallet.Sdk;
using SimpleJSON;
using System;
using System.Collections;
using System.Collections.Generic;
using TMPro;
using UnityEngine;
using UnityEngine.UI;

public class ConfirmNftPurchase : MonoBehaviour
{
    public GameObject GoContainerConfirm;
    public GameObject GoLoadingIndicator;
    public GameObject GoPopupPurchaseConfirmed;

    public TMP_Text TextNftId;
    public TMP_Text TextUserName;
    public TMP_Text TextWalletAddress;
    public TMP_Text TextCannyCost;

    public Image ImageNft;

    public Sprite[] SpriteNfts;

    private string transactionHash = null;
    private bool isTransactionStatusAvailable = false;

    public static ConfirmNftPurchase Instance;

    private void Awake()
    {
        Instance = this;
    }

    private void OnEnable()
    {
        TextUserName.text = Globals.UserName;
        TextWalletAddress.text = Utils.GetTruncatedWalletAddress();
        TextNftId.text = "NFT ID #" + Globals.CurrentlyPurchasingNftId;
        TextCannyCost.text = Globals.CurrentlyPurchasingNftPrice;

        int spriteIndex = Convert.ToInt32(Globals.CurrentlyPurchasingNftId);
        ImageNft.sprite = SpriteNfts[spriteIndex];
    }

    public void CloseConfirmPurchasePopup()
    {
        GoContainerConfirm.SetActive(false);
    }

    public void BuyNft()
    {
        GoLoadingIndicator.SetActive(true);
        WalletHandler.Instance.GetNftPurchaseApproval();
    }

    public void SendPurchaseNftRequest(TransactionInfo transaction, string nftName)
    {
        Debug.Log("SendPurchaseNftRequest called with status: " + transaction.status);
        if (transaction.status == "failed")
        {
            Debug.Log("DemoGame: Nft transaction failed. Aborting.");
            // TODO: Update UI
            isTransactionStatusAvailable = true;
            return;
        }
        if (transaction.status == "success")
        {
            isTransactionStatusAvailable = true;
           
            Debug.Log("DemoGame: SendPrucaseNftRequestDelayed called");
          

            NftItem item = NftShopHandler.Instance.GetNftItemDetails(Globals.CurrentlyPurchasingNftId);
            //string nftName = item.name;

            string walletAddresss = Utils.GetWalletAddress();
            Debug.Log($"DemoGame: name: {nftName}, address: {walletAddresss}");

            JSONNode data;
            data = JSON.Parse("{}");
            data["nft_type"] = nftName;
            data["buyer_address"] = Utils.GetWalletAddress();

            StartCoroutine(Utils.SendPostRequest(Constants.NftPurchaseEndpoint, data, NftPurchaseResponseHandler));
        }
    }

    

    private void NftPurchaseResponseHandler(string apiResponse)
    {
        Debug.Log("DemoGame: NftPurchase respo: " + apiResponse);

        JSONNode responseObj = JSON.Parse(apiResponse);
        bool isSuccess = responseObj["success"].AsBool;
        if (isSuccess)
        {
            var txnId = responseObj["transactionId"].Value;
            Debug.Log($"NFT purchased: txn id: {txnId}");
            NftPurchaseCompleted(apiResponse);
        }
    }

    public void NftPurchaseCompleted(string reason)
    {
        GoLoadingIndicator.SetActive(false);
        GoContainerConfirm.SetActive(false);
        GoLoadingIndicator.SetActive(false);
        GoPopupPurchaseConfirmed.SetActive(true);
    }
}
