using System;
using System.Collections;
using gg.now.wallet.Sdk;
using TMPro;
using UnityEngine;
using UnityEngine.SceneManagement;
using UnityEngine.UI;

public class MainMenuHandler : MonoBehaviour
{
    public GameObject GoLoginButton;
    public GameObject GoContainerProfile;
    public GameObject GoPopupLogin;
    public GameObject GoPopupCannyPurchased;
    public GameObject GoPopupBuyCanny;
    public GameObject GoLoadingIndicator;

    public Image ImageAvatar;
    public TMP_Text TextUserName;
    public TMP_Text TextWalletAddress;

    public TMP_Text TextCannyPrice;
    public TMP_Text TextCannySelected;
    public TMP_Text TextCannyCount;
    public TMP_Text TextCannyPuchasedCount;


    private int currentSelectedCannyCount = 20;
    private const int CANNY_INCREMENT_COUNT = 20;
    private const float CANNY_PRICE_USD = 0.75f;
    private bool isViaPurchaseFlow = false;

    public static MainMenuHandler Instance;

    private void Awake()
    {
        Instance = this;
    }

    private void Start()
    {
        

        SetProfileDetails();
    }

    public void SetProfileDetailsHelper()
    {
        Invoke("SetProfileDetails", 1);
    }

    public void SetProfileDetails()
    {
        if (Globals.IsUserLoggedIn == false)
        {
            GoLoginButton.SetActive(true);
            GoContainerProfile.SetActive(false);

        }
        else
        {
            GoLoginButton.SetActive(false);
            GoContainerProfile.SetActive(true);

            TextUserName.text = Globals.UserName;
            Debug.Log("DemoGame: wallet address: " + Utils.GetWalletAddress());
            TextWalletAddress.text = Utils.GetTruncatedWalletAddress();

            TextCannyCount.text = Globals.NumCannies.ToString();

            isViaPurchaseFlow = false;
            UpdateCannyBalance();
        }
        HideLoginPopup();
    }

    public void UpdateCannyBalanceAfterPurchase()
    {
        GoLoadingIndicator.SetActive(false);
        isViaPurchaseFlow = true;
        Invoke("UpdateCannyBalance", 0.5f);
        //UpdateCannyBalance();
    }

    public void UpdateCannyBalance()
    {
        GoPopupBuyCanny.SetActive(false);
        NowGGWalletSdkManager.Instance.GetTokenBalance(Constants.CoinContractAddress,Constants.CAIPChainId,
            Utils.GetWalletAddress(), OnTokenRespSuccess, OnTokenRespError);

        if (isViaPurchaseFlow)
        {
            TextCannyPuchasedCount.text = Globals.CurrentlyBuyingCannyCount.ToString() + " Canny";
            GoPopupCannyPurchased.SetActive(true);
        }
    }

    private void OnTokenRespSuccess(string tokenBalance)
    {
        Debug.Log("DemoGame: Got token balance: " + tokenBalance);
        Globals.NumCannies = (int)Convert.ToDouble(tokenBalance);
        TextCannyCount.text = Globals.NumCannies.ToString();
    }

    private void OnTokenRespError(string message)
    {
        Debug.Log("DemoGame: Got OnTokenRespError: " + message);
    }

    private void OnEnable()
    {
        SetCannyTexts();
    }

    public void CloseCannyPurchasedConfirmationPopup()
    {
        GoPopupCannyPurchased.SetActive(false);
    }

    public void Login()
    {
        GoPopupLogin.SetActive(true);
    }

    public void ShowNftShop()
    {
        SceneManager.LoadScene("NftShop");
    }

    public void ShowBuyCannyPopup()
    {
        GoPopupBuyCanny.SetActive(true);
    }

    public void ShowProfile()
    {
        SceneManager.LoadScene("UserProfile");
    }

    public void HideLoginPopup()
    {
        GoLoadingIndicator.SetActive(false);
        GoPopupLogin.SetActive(false);
    }

    public void HideBuyCannyPopup()
    {
        GoPopupBuyCanny.SetActive(false);
    }

    public void LoginWithNowGGWallet()
    {
        WalletHandler.Instance.ConnectNowGGWallet();
        GoLoadingIndicator.SetActive(true);
    }

    public void IncreaseCannySelectedCount()
    {
        if (currentSelectedCannyCount > 2000)
            return;

        currentSelectedCannyCount += CANNY_INCREMENT_COUNT;

        SetCannyTexts();
    }

    public void DecreaseCannySelectedCount()
    {
        if (currentSelectedCannyCount <= CANNY_INCREMENT_COUNT)
            return;

        currentSelectedCannyCount -= CANNY_INCREMENT_COUNT;
        SetCannyTexts();
    }

    private void SetCannyTexts()
    {
        float currentSelectedCannyPrice = currentSelectedCannyCount * CANNY_PRICE_USD;

        TextCannySelected.text = currentSelectedCannyCount.ToString();
        TextCannyPrice.text = string.Format("{0} CANNY = $ {1:0.00}",
            currentSelectedCannyCount, currentSelectedCannyPrice);
    }

    public void InitiateBuyCanny()
    {
        Debug.Log("DemoGame: Buying: " + currentSelectedCannyCount);
        GoLoadingIndicator.SetActive(true);
        Invoke("HideLoadingIndicator", 60);
        Globals.CurrentlyBuyingCannyCount = currentSelectedCannyCount;
        WalletHandler.Instance.BuyCanny(currentSelectedCannyCount);
    }

    private void HideLoadingIndicator()
    {
        GoLoadingIndicator.SetActive(true);
    }
}
