using System;
using System.Collections.Generic;
using gg.now.wallet.Sdk;
using TMPro;
using UnityEngine;
using UnityEngine.SceneManagement;
using UnityEngine.UI;

public class UserProfileHandler : MonoBehaviour
{
    public Image ImageAvatar;
    public TMP_Text TextUserName;
    public TMP_Text TextWalletAddress;
    public TMP_Text TextCannyCount;

    public GameObject GoNftFroggy;
    public GameObject GoNftBirdie;
    public GameObject GoNftPengu;
    public GameObject GoNftFlyie;
    public GameObject GoNftRabby;

    public GameObject GoLoadingSpinner;

    private int retryFetchingNftsCount = 3;

    private void Start()
    {
        GoLoadingSpinner.SetActive(true);

        TextUserName.text = Globals.UserName;
        TextWalletAddress.text = Utils.GetTruncatedWalletAddress();
        TextCannyCount.text = Globals.NumCannies.ToString();

        HideAllNfts();

        Invoke("FetchNfts", 5);
        Invoke("HideLoadingSpinner", 30);
    }

    public void FetchNfts()
    {
        NowGGWalletSdkManager.Instance.GetNfts(Constants.CAIPChainId, Utils.GetWalletAddress(),
            OnNftsReceived, OnGetNftError);
    }

    public void HideLoadingSpinner()
    {
        GoLoadingSpinner.SetActive(false);
    }

    public void ShowLoadingSpinner()
    {
        GoLoadingSpinner.SetActive(true);
    }

    public void HideAllNfts()
    {
        GoNftFroggy.SetActive(false);
        GoNftBirdie.SetActive(false);
        GoNftPengu.SetActive(false);
        GoNftFlyie.SetActive(false);
        GoNftRabby.SetActive(false);
    }

    private void OnGetNftError(string message)
    {
        Debug.Log("OnGetNftError: " + message);
        //todo: show error or update UI
    }

    private void OnNftsReceived(List<Nft> nfts)
    {
        Debug.Log("OnNftsReceived called");

        try
        {
            foreach (Nft n in nfts)
            {
                string name = n.metadata?.name;
                Debug.Log("DemoGame: got nft: " + name);

                if (string.Equals(name, "froggy", StringComparison.OrdinalIgnoreCase))
                    GoNftFroggy.SetActive(true);
                else if (string.Equals(name, "birdie", StringComparison.OrdinalIgnoreCase))
                    GoNftBirdie.SetActive(true);
                else if (string.Equals(name, "penguin", StringComparison.OrdinalIgnoreCase))
                    GoNftPengu.SetActive(true);
                else if (string.Equals(name, "flyie", StringComparison.OrdinalIgnoreCase))
                    GoNftFlyie.SetActive(true);
                else if (string.Equals(name, "rabbie", StringComparison.OrdinalIgnoreCase))
                    GoNftRabby.SetActive(true);
            }

            HideLoadingSpinner();
        }
        catch (Exception e)
        {
            Debug.Log("Demogame: "+ e.StackTrace);
            Debug.Log("DemoGame: Exception in getting NFTs. Retrying...");
            if (retryFetchingNftsCount-- > 0)
            {
                Invoke("FetchNfts", 2);
            }
        }
    }

    public void ShowMainMenu()
    {
        SceneManager.LoadScene("MainMenu");
    }
}

