using System.Collections.Generic;
using gg.now.wallet.Sdk;
using UnityEngine;
using UnityEngine.SceneManagement;

public class WalletHandler
{
    private static WalletHandler instance;
    private List<VoidCallback> OnConnectCallbacks = new List<VoidCallback>();
   
       
    public static WalletHandler Instance
    {
        get
        {
            if (instance == null)
                instance = new WalletHandler();
            return instance;
        }
    }

    public void AddOnConnectCallback(VoidCallback onConnectCallback)
    {
        if (onConnectCallback != null)
        {
            OnConnectCallbacks.Add(onConnectCallback);
        }
    }

    public void RemoveOnConnectCallback(VoidCallback onConnectCallback)
    {
        OnConnectCallbacks.Remove(onConnectCallback);
    }

    public void Init(VoidCallback initSuccessCallback)
    {
        WalletDelegateHandler delegateHandler = new WalletDelegateHandler();
        delegateHandler.OnConnectSuccessfulListener = () =>
        {
            foreach (VoidCallback callback in OnConnectCallbacks)
            {
                callback();
            }
            OnConnectCallbacks.Clear();
            delegateHandler.OnConnectSuccessfulListener = null;
        };

        NowGGWalletSdkManager.Instance.Initialize(Constants.ApiKey, Constants.AppId, delegateHandler, initSuccessCallback, (error) => {
            Debug.Log("Error occured while initialising sdk");
        });
    }


    public void ConnectNowGGWallet()
    {
        Debug.Log("DemoGame: ConnectNowGGWallet called");
        try
        {
            NowGGWalletSdkManager.Instance.Connect(Constants.CAIPChainId,
           OnPairingInvoked, OnConnectError);
        }
        catch (SocketNotConnectedException)
        {
            Utils.ShowAndroidToastMessage("Please check your connectivity");
        }
        catch (WalletSdkNotInitialisedException)
        {
            Utils.ShowAndroidToastMessage("Please initialise the sdk first");
        }

    }

    public void BuyCanny(int amount)
    {
        try
        {

            NowGGWalletSdkManager.Instance.BuyToken(Constants.CoinContractAddress,
                amount.ToString(), Constants.CAIPChainId, "BuyToken");
        }
        catch (SocketNotConnectedException)
        {
            Utils.ShowAndroidToastMessage("Please check your connectivity");
        }
        catch (WalletSdkNotInitialisedException)
        {
            Utils.ShowAndroidToastMessage("Please initialise the sdk first");
        }
    }

    void OnConnectError(string error)
    {
        Debug.Log("DemoGame: Failed to connect to wallet. Error: " + error);
        Utils.ShowAndroidToastMessage(error);
    }

    void OnPairingInvoked()
    {
        Debug.Log("DemoGame: OnPairingInvoked called");
    }

    public void GetNftPurchaseApproval()
    {
        Debug.Log("DemoGame: GetNftPurchaseApproval called");

        NftItem item = NftShopHandler.Instance.GetNftItemDetails(Globals.CurrentlyPurchasingNftId);
        string nftData = item.data;
        try
        {
            NowGGWalletSdkManager.Instance.SendTransaction(
                Constants.CoinContractAddress,
                "0x0", nftData, Constants.CAIPChainId, item.name);
        }
        catch (SocketNotConnectedException)
        {
            Utils.ShowAndroidToastMessage("Please check your connectivity");
        }
        catch (WalletSdkNotInitialisedException)
        {
            Utils.ShowAndroidToastMessage("Please initialise the sdk first");
        }
    }



}


public class WalletDelegateHandler : NowGGWalletDelgate
{
    public VoidCallback OnConnectSuccessfulListener;

    public void OnConnectionStateChange(bool isAvailable)
    {
        Globals.isConnected = isAvailable;
        if (isAvailable && (Globals.SessionTopic == "" || Globals.SessionTopic == null))
        {
            if (OnConnectSuccessfulListener != null)
            {
                OnConnectSuccessfulListener();
            }
        }
    }

    public void OnError(string error)
    {
        Debug.LogError(error);
        if (error == ErrorCodes.SESSION_EXPIRED)
        {
            Utils.ShowAndroidToastMessage(error);
            Globals.IsUserLoggedIn = false;
            Globals.NumCannies = 0;
            SceneManager.LoadScene("MainMenu");

        }
    }

  

    public void OnSessionApproved(ApprovedSession approvedSession, User user)
    {
        Globals.SessionTopic = approvedSession.topic;
        Globals.WalletAddress = approvedSession.accounts[0];
        Debug.Log($"DemoGame: wallet address: {Globals.WalletAddress}");
        Globals.IsUserLoggedIn = true;
        Globals.UserName = user.name;

        MainMenuHandler.Instance.SetProfileDetailsHelper();
    }

    public void OnSessionDelete(DeletedSession deletedSession)
    {
    }

    public void OnSessionRejected(RejectedSession rejectedSession)
    {
    }

    public void OnSessionUpdate(UpdatedSession updatedSession)
    {
    }

    public void OnTokenPurchaseError(string error, string extra)
    {
        Debug.Log("OnBuyCannyError: " + error);
    }

    public void OnTokenPurchaseSuccess(JsonRpcResponse result, string extra)
    {
        Debug.Log("DemoGame: OnTokenPurchaseResponse : " + result.ToString() + $" extra:{extra}");
        MainMenuHandler.Instance.UpdateCannyBalanceAfterPurchase();
    }

    public void OnTransactionCompletedError(string error, string extra)
    {
        Debug.Log($"Transaction completed with error: {error}, extra: {extra}");
    }

    public void OnTransactionCompletedSuccess(TransactionInfo transaction, string extra)
    {
        Debug.Log($"Demogame: Transaction status:{transaction.status} : transaction id:{transaction.transactionHash} : extra:{extra}");
        ConfirmNftPurchase.Instance.SendPurchaseNftRequest(transaction, extra);
    }

    public void OnTransactionSendError(string error, string extra)
    {
        Debug.Log("DemoGame: OnNftBuyError: " + error);
    }

    public void OnTransactionSendSuccess(string txnHash, string caipChainId, string extra)
    {
        Debug.Log("DemoGame: OnSessionrequestResponse called");
        Debug.Log($"DemoGame:extra: {extra}");
        Debug.Log($"DemoGame: txn hash: {txnHash}");
    }


}
